@@ -1,11 +1,10 @@
-# -*- coding: utf-8 -*-
 from zope import schema
 from zope.interface import Interface
 
 import zope.i18nmessageid
 
 
-_ = zope.i18nmessageid.MessageFactory('plone.app.caching')
+_ = zope.i18nmessageid.MessageFactory("plone.app.caching")
 
 
 class ICacheProfiles(Interface):
@@ -38,33 +37,38 @@ class IPloneCacheSettings(Interface):
     """
 
     templateRulesetMapping = schema.Dict(
-        title=_(u'Page template/ruleset mapping'),
-        description=_(u'Maps skin layer page template names to ruleset names'),
-        key_type=schema.ASCIILine(title=_(u'Page template name')),
-        value_type=schema.DottedName(title=_(u'Ruleset name')),
+        title=_("Page template/ruleset mapping"),
+        description=_("Maps skin layer page template names to ruleset names"),
+        key_type=schema.ASCIILine(title=_("Page template name")),
+        value_type=schema.DottedName(title=_("Ruleset name")),
     )
 
     contentTypeRulesetMapping = schema.Dict(
-        title=_(u'Content type/ruleset mapping'),
-        description=_(u'Maps content type names to ruleset names'),
-        key_type=schema.ASCIILine(title=_(u'Content type name')),
-        value_type=schema.DottedName(title=_(u'Ruleset name')),
+        title=_("Content type/ruleset mapping"),
+        description=_("Maps content type names to ruleset names"),
+        key_type=schema.ASCIILine(title=_("Content type name")),
+        value_type=schema.DottedName(title=_("Ruleset name")),
     )
 
     purgedContentTypes = schema.Tuple(
-        title=_(u'Content types to purge'),
-        description=_(
-            u'List content types which should be purged when modified'),
-        value_type=schema.ASCIILine(title=_(u'Content type name')),
-        default=('File', 'Image', 'News Item', ),
+        title=_("Content types to purge"),
+        description=_("List content types which should be purged when modified"),
+        value_type=schema.ASCIILine(title=_("Content type name")),
+        default=(
+            "File",
+            "Image",
+            "News Item",
+        ),
     )
 
     cacheStopRequestVariables = schema.Tuple(
-        title=_(u'Request variables that prevent caching'),
-        description=_(
-            u'Variables in the request that prevent caching if present'),
-        value_type=schema.ASCIILine(title=_(u'Request variables')),
-        default=('statusmessages', 'SearchableText', ),
+        title=_("Request variables that prevent caching"),
+        description=_("Variables in the request that prevent caching if present"),
+        value_type=schema.ASCIILine(title=_("Request variables")),
+        default=(
+            "statusmessages",
+            "SearchableText",
+        ),
     )
 
 
@@ -72,14 +76,13 @@ class IETagValue(Interface):
     """ETag component builder
 
     Register a named multi-adapter from ``(published, request)`` to this
-    interface to provide the values for ETag compnents. Various caching
+    interface to provide the values for ETag components. Various caching
     operations will look up such adapters to compose an ETag value. The
     adapter name is used in options configuring those components.
     """
 
     def __call__():
-        """Return the ETag component, as a string.
-        """
+        """Return the ETag component, as a string."""
 
 
 class IRAMCached(Interface):
